@@ -9,14 +9,14 @@ T = TypeVar("T")
 LEAN_CLASS_KEY = "__leanapi_class__"
 
 
-def controller(path: str, router: APIRouter, depend: Callable[None] = None) -> Callable[[Type[T]], Type[T]]:
+def controller(path: str, router: APIRouter, depend: Callable[..., None] = None) -> Callable[[Type[T]], Type[T]]:
     def decorator(cls: Type[T]) -> Type[T]:
-        return _controller(router, path, cls, [Depends(_call)] if _call else None)
+        return _controller(router, path, cls, [Depends(depend)] if depend else None)
 
     return decorator
 
 
-def _controller(router: APIRouter, path: str, cls: Type[T], _call:Any) -> Type[T]:
+def _controller(router: APIRouter, path: str, cls: Type[T], _call:Any = None ) -> Type[T]:
     """
     Replaces any methods of the provided class `cls` that are endpoints of routes in `router` with updated
     function calls that will properly inject an instance of `cls`.
